class PopupWindow:
    def __init__(self, title="Popup", message="Hello"):
        self.title = title
        self.message = message

    def show(self):
        self.draw()

    def draw(self):
        print("=" * 30)
        print(f"{self.title}")
        print("-" * 30)
        print(self.message)
        print("=" * 30)