class PopupApp:
    def __init__(self):
        self.windows = []

    def add_window(self, window):
        self.windows.append(window)

    def run(self):
        for window in self.windows:
            window.show()